==> scala-1.3.0.2.tar.gz: scala-1.3.0.2/src/scala/xml/DocType.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2003-2004, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
** $Id: DocType.scala,v 1.3 2004/08/20 10:31:51 buraq Exp $
\*                                                                      */

package scala.xml;

/** an XML node for document type declaration
 *
 * @author Burak Emir
 * @param  target name of this DOCTYPE
 * @param  extID  None, or Some(external ID of this doctype)
 * @param  intSubset sequence of internal subset declarations
**/

case class DocType( name:String, extID:ExternalID, intSubset:Seq[dtd.Decl]) {  

  if( !Parsing.isName( name ) ) 
    throw new IllegalArgumentException(name+" must be an XML Name");

  /** hashcode for this processing instruction */
  final override def hashCode() = name.hashCode() + 7 * extID.hashCode() + 41*intSubset.toList.hashCode();

  /** returns "<!DOCTYPE + name + extID? + ("["+intSubSet+"]")? >" */
  final override def toString() = {
    val sb = new StringBuffer("<!DOCTYPE ");
    sb.append( name );
    sb.append(' ');
    sb.append(extID.toString());
    if( intSubset.length > 0 ) {
      sb.append('[');
      for( val d <- intSubset ) {
        sb.append( d.toString() );
      }
      sb.append(']');
    }
    sb.append('>');
    sb.toString();
  }
}

==> scala-1.3.0.9.tar.gz: scala-1.3.0.9/src/scala/xml/DocType.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2003-2004, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
** $Id: DocType.scala,v 1.4 2004/09/28 09:00:21 buraq Exp $
\*                                                                      */

package scala.xml;

/** an XML node for document type declaration
 *
 * @author Burak Emir
 * @param  target name of this DOCTYPE
 * @param  extID  None, or Some(external ID of this doctype)
 * @param  intSubset sequence of internal subset declarations
**/

case class DocType( name:String, extID:ExternalID, intSubset:Seq[dtd.Decl]) {  

  if( !Parsing.isName( name ) ) 
    throw new IllegalArgumentException(name+" must be an XML Name");

  /** hashcode for this processing instruction */
  final override def hashCode() = name.hashCode() + 7 * extID.hashCode() + 41*intSubset.toList.hashCode();

  /** returns "&lt;!DOCTYPE + name + extID? + ("["+intSubSet+"]")? >" */
  final override def toString() = {
    val sb = new StringBuffer("<!DOCTYPE ");
    sb.append( name );
    sb.append(' ');
    sb.append(extID.toString());
    if( intSubset.length > 0 ) {
      sb.append('[');
      for( val d <- intSubset ) {
        sb.append( d.toString() );
      }
      sb.append(']');
    }
    sb.append('>');
    sb.toString();
  }
}
